@@ -30,6 +30,7 @@ import requests
 import six
 import sys
 import textwrap
+import logging
 import threading
 import warnings
 import xml.etree.ElementTree as ET
@@ -58,11 +59,16 @@ from .utils.data import get_project_data, gen_name, get_server_info
 from .utils.events import get_events
 from .utils.keyword import dekeywordify
 from .utils.project import expand_path
-from .websocket import WebSocketClient
+from .websocket import createWebSocket
 from .windows import BaseWindow, get_window_class
 from .espapi import api
 from .espapi import k8s
 
+if os.getenv("ESPPY_LOG") != None:
+    for handler in logging.root.handlers[:]:
+        logging.root.removeHandler(handler)
+    logging.basicConfig(filename=os.getenv("ESPPY_LOG"),level=logging.INFO)
+
 class ProjectStats(object):
     '''
     Project statistics subscriber
@@ -194,7 +200,7 @@ class ProjectStats(object):
         if get_option('debug.requests'):
             sys.stderr.write('WEBSOCKET %s\n' % self.url)
 
-        self._ws = WebSocketClient(self.url,self.session,on_message=on_message)
+        self._ws = createWebSocket(self.url,self.session,on_message=on_message)
         self._ws.connect()
 
     def stop(self):
@@ -241,6 +247,10 @@ class ESP(RESTHelpers):
     protocol : string, optional
         The protocol to use: http or https.  This is not
         needed if a URL is used in the first parameter.
+    model_file: string, optional
+        Path to the ESP model to load
+    model_data: string, optional
+        The ESP model to load
     ca_bundle : string, optional
         Path to the certificate bundle if using SSL
     authinfo : string, optional
@@ -278,8 +288,9 @@ class ESP(RESTHelpers):
     Template = template.Template
 
     def __init__(self, hostname=None, port=None, username=None,
-                 password=None, protocol=None, ca_bundle=None,
-                 authinfo=None, auth_obj=None):
+                 password=None, protocol=None, 
+                 model_file=None, model_data=None,
+                 ca_bundle=None, authinfo=None, auth_obj=None):
         # Use environment variables as needed
         if hostname is None and get_option('hostname'):
             hostname = get_option('hostname')
@@ -293,10 +304,21 @@ class ESP(RESTHelpers):
             protocol = get_option('protocol')
 
         self._k8s = None
+        self._ca_bundle = ca_bundle
 
-        if re.match('^k8s.*://', hostname):
-            self._k8s = k8s.create(hostname)
-            hostname = self._k8s.espUrl
+        if re.match('^k8s.*://',hostname):
+            opts = {}
+            if model_file != None:
+                opts["model_file"] = model_file
+            elif model_data != None:
+                opts["model_data"] = model_data
+            if username is not None:
+                opts["username"] = username
+            if password is not None:
+                opts["password"] = password
+            self._k8s = k8s.create(hostname,self,**opts)
+            if self._k8s.project is not None:
+                hostname = self._k8s.espUrl
 
         # Set default protocol
         if not protocol:
@@ -355,6 +377,12 @@ class ESP(RESTHelpers):
         # Use specified auth object
         if auth_obj is not None:
             session.auth = auth_obj
+        elif self._k8s is not None:
+            if self._k8s.hasOpt("access_token"):
+                token = self._k8s.getOpt("access_token")
+                auth.setBearer(token)
+                self._authorization = "Bearer " + token
+                session.headers.update({'Authorization':self._authorization.encode("utf-8")})
         else:
             enable_kerberos = username is None and password is None
 
@@ -395,24 +423,36 @@ class ESP(RESTHelpers):
                                   'module is not installed ', RuntimeWarning)
                     raise ESPError(res.reason)
 
+        if self._k8s is not None:
+            self.accessToken = self._k8s.getOpt("access_token")
+
         RESTHelpers.__init__(self, session=session)
 
         version = self.server_info["version"]
 
-        rgx = re.compile(".*\(([0-9]\.[0-9])\)")
+        rgx = re.compile(".*\(([0-9]*)\.([0-9]*)\)")
 
         match = rgx.findall(version)
 
         if len(match) == 1:
-            self._version = float(match[0])
+            self._major = int(match[0][0])
+            self._minor = int(match[0][1])
         else:
-            self._version = float(version)
+            a = version.split(".")
+            self._major = int(a[0])
+            self._minor = int(a[1])
 
-        if self._version < 5.2:
+        if self._major < 5 and self._minor < 2:
             raise RuntimeError('This package requires an ESP server version 5.2 or greater')
 
         self._populate_algorithms()
 
+        if self._k8s == None:
+            if model_file != None:
+                self.load_project_from_file(model_file,overwrite=True)
+            elif model_data != None:
+                self.load_project(model_data,overwrite=True)
+
     def __str__(self):
         return '%s(%s)' % (type(self).__name__,
                            repr(self.base_url.replace('/%s/' % ESP_ROOT, '')))
@@ -431,7 +471,12 @@ class ESP(RESTHelpers):
         requests_log.propagate = True
 
     def createServerConnection(self,**kwargs):
-        return(api.connect(self.session,self._k8s,**kwargs))
+        conn = api.connect(self,**kwargs)
+        return(conn)
+
+    @property
+    def ca_bundle(self):
+        return(self._ca_bundle)
 
     @property
     def authorization(self):
@@ -902,7 +947,11 @@ class ESP(RESTHelpers):
             Name of the project to delete
 
         '''
-        self._delete('projects/%s' % name)
+
+        if self._k8s != None:
+            self._k8s.delete()
+        else:
+            self._delete('projects/%s' % name)
 
     def get_running_projects(self, name=None, filter=None):
         '''
@@ -1630,6 +1679,8 @@ class ESP(RESTHelpers):
         '''
         return self._get('logs', raw=True).rstrip().split('\n')
 
+    def createWebSocket(self,url,on_open=None,on_close=None,on_message=None,on_data=None,on_error=None,headers=None,ws4py=True,**kwargs):
+        return(createWebSocket(url,self.session,on_open=on_open,on_close=on_close,on_message=on_message,on_data=on_data,on_error=on_error,headers=headers,ws4py=ws4py,**kwargs))
 
 def get_subclasses(cls):
     for subclass in cls.__subclasses__():
