@@ -57,7 +57,6 @@ from ..utils.notebook import scale_svg
 from ..utils.rest import get_params
 from ..utils.data import get_project_data, gen_name, get_server_info
 from ..utils.events import get_events, get_dataframe, get_schema
-from ..websocket import WebSocketClient
 
 INDEX_TYPES = {
     'rbtree': 'pi_RBTREE',
@@ -1061,7 +1060,7 @@ class BaseWindow(ESPObject):
         '''
         self._project = getattr(value, 'name', value)
 
-    def create_event_generator(self, data=None, name=None, overwrite=False):
+    def create_event_generator(self, xml=None, data=None, name=None, overwrite=False):
         '''
         Create an event generator
 
@@ -1096,7 +1095,12 @@ class BaseWindow(ESPObject):
 
         '''
         from ..evtgen import EventGenerator
-        gen = EventGenerator(name=name)
+        if xml != None:
+            gen = EventGenerator.from_xml(xml)
+            if name != None:
+                gen.name = name
+        else:
+            gen = EventGenerator(name=name)
         gen.session = self.session
         gen.publish_target = self
         if data is not None:
@@ -1249,8 +1253,9 @@ class BaseWindow(ESPObject):
         def _flatten_map(p):
             l = list(p.values()) if p else []
             flat_list = []
-            _ = [flat_list.extend(item) if isinstance(item, list)
+            _ = [flat_list.extend(item) if isinstance(item, (list, tuple))
                  else flat_list.append(re.sub(r'\[[^\]]+\]$', r'', item)) for item in l if item]
+            flat_list = [x.strip().split(':', 1)[0] for x in flat_list]
             return flat_list
 
         def _propagate_schema(*source_win, target_win):
